import logging

import bpy
from bpy.utils import unregister_class, register_class

from render_polargrid.wheels import load_wheels
load_wheels()

from render_polargrid.space_preferences import (
    PGPreferences,
    PGRequestTokenOperator,
    PGValidateTokenOperator,
)
from render_polargrid.space_properties import (
    PGRenderPanel,
    PGScenePanel,
    PGPhysicsPanel,

    PGRenderOperator,
    PGViewJobsOperator,
    PGNewSceneIDOperator,
)
from render_polargrid.data_scene import (
    PGScenePropertyGroup,
)
from render_polargrid.data_wm import (
    PGWMPropertyGroup,
    PGFetchPoolsOperator,
)
from render_polargrid.handlers import (
    post_load_handler,
)
from render_polargrid.async_loop import AsyncLoopModalOperator, setup_asyncio_executor

logger = logging.getLogger(__name__)

bl_info = {
    "name": "PolarGrid Renderfarm",
    "author": "PolarGrid",
    "version": (1, 0, 0),
    "blender": (2, 83, 0),
    "location": "",
    "description": "PolarGrid Renderfarm",
    "warning": "",
    "wiki_url": "",
    "category": "Render",
}


classes = (
    AsyncLoopModalOperator,

    PGPreferences,
    PGRequestTokenOperator,
    PGValidateTokenOperator,

    PGScenePropertyGroup,
    PGWMPropertyGroup,

    PGRenderPanel,
    PGRenderOperator,
    PGViewJobsOperator,
    PGFetchPoolsOperator,

    PGScenePanel,
    PGNewSceneIDOperator,

    PGPhysicsPanel,
)


def register():
    setup_asyncio_executor()
    for cls in classes:
        register_class(cls)

    bpy.types.Scene.polargrid = bpy.props.PointerProperty(
        type=PGScenePropertyGroup,
    )
    bpy.types.WindowManager.polargrid = bpy.props.PointerProperty(
        type=PGWMPropertyGroup,
    )
    bpy.app.handlers.load_post.append(post_load_handler)


def unregister():
    for cls in reversed(classes):
        unregister_class(cls)
    # bpy.app.handlers.load_post.remove(post_load_handler)


if __name__ == "__main__":
    register()
